// Force strict mode and setup for ESM
"use strict";
import {
  require_undici
} from "./chunk-E7E2MFYM.js";
import "./chunk-A4BMJM77.js";
import "./chunk-J2S4EL5Y.js";
export default require_undici();
